summaryrefslogtreecommitdiff
path: root/driver_ubx.c
diff options
context:
space:
mode:
authorEric S. Raymond <esr@thyrsus.com>2009-07-24 18:37:42 +0000
committerEric S. Raymond <esr@thyrsus.com>2009-07-24 18:37:42 +0000
commita387bd933fa39a2da8a1015aaddbeb9a42c7036a (patch)
treef331abecd5c696cecbd4d7522d2e2688c37ca15a /driver_ubx.c
parent365650338b14fbbb96533aa2a7c49835039273cb (diff)
downloadgpsd-a387bd933fa39a2da8a1015aaddbeb9a42c7036a.tar.gz
Add and document the device_class member, so we can do ?DEVICES properly.
Diffstat (limited to 'driver_ubx.c')
-rw-r--r--driver_ubx.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/driver_ubx.c b/driver_ubx.c
index 83b684ce..db8c3bc7 100644
--- a/driver_ubx.c
+++ b/driver_ubx.c
@@ -714,7 +714,8 @@ static bool ubx_rate(struct gps_device_t *session, double cycletime)
/* This is everything we export */
const struct gps_type_t ubx_binary = {
.type_name = "uBlox UBX binary", /* Full name of type */
- .packet_type = UBX_PACKET, /* associated lexer packet type */
+ .packet_type = UBX_PACKET, /* associated lexer packet type */
+ .device_class = GPS, /* it's a GPS */
.trigger = NULL, /* Response string that identifies device (not active) */
.channels = 50, /* Number of satellite channels supported by the device */
.probe_detect = NULL, /* Startup-time device detector */